function classifyResult = challenge(recordName)
%
% Sample entry for the 2017 PhysioNet/CinC Challenge.
%
% INPUTS:
% recordName: string specifying the record name to process
%
% OUTPUTS:
% classifyResult: integer value where
%                     N = normal rhythm
%                     A = AF
%                     O = other rhythm
%                     ~ = noisy recording (poor signal quality)
%
% To run your entry on the entire training set in a format that is
% compatible with PhysioNet's scoring enviroment, run the script
% generateValidationSet.m
%
% The challenge function requires that you have downloaded the challenge
% data 'training_set' in a subdirectory of the current directory.
%    http://physionet.org/physiobank/database/challenge/2017/
%
% This dataset is used by the generateValidationSet.m script to create
% the annotations on your training set that will be used to verify that
% your entry works properly in the PhysioNet testing environment.
%
%
% Version 1.0
%
%
% Written by: Chengyu Liu and Qiao Li January 20 2017
%             chengyu.liu@emory.edu  qiao.li@emory.edu
%
% Last modified by: ATL
% Date of modification: 19/04/2017 17:33
%

classifyResult = 'N'; % default output normal rhythm

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %%
%                             LOAD SIGNAL                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[tm,ecg,fs,siginfo]=rdmat(recordName);

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %%
%                              FEATURES                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% AFEv
[QRS,sign,en_thres] = qrs_detect2(ecg',0.25,0.6,fs);
if length(QRS)<6
    ecg_AFEv = NaN;
else
    RR=diff(QRS')/fs;
    ecg_AFEv = comput_AFEv(RR);
%     if ecg_AFEv>1
%         classifyResult = 'A';
%     end
end

% Entropy
ecg_entropy = entropy(ecg);

% P-R ratio
[ecg_PR_ratio,~,~] = calcular_PR_ratio(ecg);

% Dominant Frequency of the autocorrelation of the signal
ecg_autocorr = autocorr(ecg,length(ecg)-1);
ecg_autocorr_DF = calcular_DFS(ecg_autocorr');

% Dominant Frequency of the QRS removed signal
ecg_rQRS_DF = calcular_DF_QRScancelado(ecg);
 
% Mean signal
ecg_mean = mean(ecg);

% Std signal
ecg_std = std(ecg);

% Subbands energy
[ ecg_band1, ecg_band2, ecg_band3 ] = calcular_energia_subbandas( ecg );

% Amplitude
[ecg_prom_amp, ecg_std_amp] = calcular_amplitud(ecg);

% Peak stats
try
    peak_stats = peakstats(1:length(ecg),ecg,0.01,-1,5,19,3,0);

    if peak_stats(4,3)>1000
        peak_stats = peakstats(1:length(ecg),-ecg,0.01,-1,5,19,3,0);
    end
    
    ecg_peak_interval_maximum = peak_stats(1,1);
    ecg_peak_interval_minimum = peak_stats(2,1);
    ecg_peak_interval_mean = peak_stats(3,1);
    ecg_peak_interval_std = peak_stats(4,1);
    ecg_peak_interval_median = peak_stats(5,1);
    ecg_peak_interval_mode = peak_stats(6,1);

    ecg_peak_height_maximum = peak_stats(1,2);
    ecg_peak_height_minimum = peak_stats(2,2);
    ecg_peak_height_mean = peak_stats(3,2);
    ecg_peak_height_std = peak_stats(4,2);
    ecg_peak_height_median = peak_stats(5,2);
    ecg_peak_height_mode = peak_stats(6,2);

    ecg_peak_width_maximum = peak_stats(1,3);
    ecg_peak_width_minimum = peak_stats(2,3);
    ecg_peak_width_mean = peak_stats(3,3);
    ecg_peak_width_std = peak_stats(4,3);
    ecg_peak_width_median = peak_stats(5,3);
    ecg_peak_width_mode = peak_stats(6,3);

    ecg_peak_area_maximum = peak_stats(1,4);
    ecg_peak_area_minimum = peak_stats(2,4);
    ecg_peak_area_mean = peak_stats(3,4);
    ecg_peak_area_std = peak_stats(4,4);
    ecg_peak_area_median = peak_stats(5,4);
    ecg_peak_area_mode = peak_stats(6,4);

catch
    

    ecg_peak_interval_maximum = NaN;
    ecg_peak_interval_minimum = NaN;
    ecg_peak_interval_mean = NaN;
    ecg_peak_interval_std = NaN;
    ecg_peak_interval_median = NaN;
    ecg_peak_interval_mode = NaN;

    ecg_peak_height_maximum = NaN;
    ecg_peak_height_minimum = NaN;
    ecg_peak_height_mean = NaN;
    ecg_peak_height_std = NaN;
    ecg_peak_height_median = NaN;
    ecg_peak_height_mode = NaN;

    ecg_peak_width_maximum = NaN;
    ecg_peak_width_minimum = NaN;
    ecg_peak_width_mean = NaN;
    ecg_peak_width_std = NaN;
    ecg_peak_width_median = NaN;
    ecg_peak_width_mode = NaN;

    ecg_peak_area_maximum = NaN;
    ecg_peak_area_minimum = NaN;
    ecg_peak_area_mean = NaN;
    ecg_peak_area_std = NaN;
    ecg_peak_area_median = NaN;
    ecg_peak_area_mode = NaN;
end
% Features vector
features = [ecg_AFEv ecg_entropy ecg_PR_ratio ecg_autocorr_DF ecg_rQRS_DF ...
    ecg_mean ecg_std ecg_band2 ecg_band3 ecg_prom_amp ecg_std_amp ...
    ecg_peak_interval_maximum ecg_peak_interval_mean ecg_peak_interval_std ...
    ecg_peak_interval_median ecg_peak_height_median ecg_peak_width_maximum ...
    ecg_peak_width_mean ecg_peak_width_std];
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% %%
%                            CLASIFICATION                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load('modelo_TreeBagger_20172404_1412.mat')
[classifyResult]=Discriminant_test(Dsc_Model,features);
classifyResult = char(classifyResult);